Media
=====

.. autoclass:: batoid.Medium
    :members:

.. autoclass:: batoid.ConstMedium
    :show-inheritance:
    :members:

.. autoclass:: batoid.TableMedium
    :show-inheritance:
    :members:

.. autoclass:: batoid.SellmeierMedium
    :show-inheritance:
    :members:

.. autoclass:: batoid.SumitaMedium
    :show-inheritance:
    :members:

.. autoclass:: batoid.Air
    :show-inheritance:
    :members:
